@@ -20,9 +20,8 @@ from typing import (
     Any,
     Literal,
     NoReturn,
-    Optional,
+    TypeAlias,
     TypeVar,
-    Union,
     cast,
     overload,
 )
@@ -75,8 +74,6 @@ from hypothesis.utils.conventions import not_set
 from hypothesis.utils.threading import ThreadLocal
 
 if TYPE_CHECKING:
-    from typing import TypeAlias
-
     from hypothesis.strategies import SearchStrategy
     from hypothesis.strategies._internal.core import DataObject
     from hypothesis.strategies._internal.random import RandomState
@@ -103,11 +100,9 @@ def __getattr__(name: str) -> Any:
 
 
 T = TypeVar("T")
-TargetObservations = dict[str, Union[int, float]]
+TargetObservations = dict[str, int | float]
 # index, choice_type, constraints, forced value
-MisalignedAt: "TypeAlias" = tuple[
-    int, ChoiceTypeT, ChoiceConstraintsT, Optional[ChoiceT]
-]
+MisalignedAt: TypeAlias = tuple[int, ChoiceTypeT, ChoiceConstraintsT, ChoiceT | None]
 
 TOP_LABEL = calc_label_from_name("top")
 MAX_DEPTH = 100
@@ -204,7 +199,7 @@ class Span:
         return self.owner.labels[self.owner.label_indices[self.index]]
 
     @property
-    def parent(self) -> Optional[int]:
+    def parent(self) -> int | None:
         """The index of the span that this one is nested directly within."""
         if self.index == 0:
             return None
@@ -324,7 +319,7 @@ class SpanRecord:
 
     def __init__(self) -> None:
         self.labels: list[int] = []
-        self.__index_of_labels: Optional[dict[int, int]] = {}
+        self.__index_of_labels: dict[int, int] | None = {}
         self.trail = IntList()
         self.nodes: list[ChoiceNode] = []
 
@@ -451,7 +446,7 @@ class Spans:
         self.__length = self.trail.count(
             TrailType.STOP_SPAN_DISCARD
         ) + record.trail.count(TrailType.STOP_SPAN_NO_DISCARD)
-        self.__children: Optional[list[Sequence[int]]] = None
+        self.__children: list[Sequence[int]] | None = None
 
     @cached_property
     def starts_and_ends(self) -> tuple[IntList, IntList]:
@@ -536,7 +531,7 @@ class DataObserver:
     def conclude_test(
         self,
         status: Status,
-        interesting_origin: Optional[InterestingOrigin],
+        interesting_origin: InterestingOrigin | None,
     ) -> None:
         """Called when ``conclude_test`` is called on the
         observed ``ConjectureData``, with the same arguments.
@@ -580,20 +575,20 @@ class ConjectureResult:
     usefulness."""
 
     status: Status = attr.ib()
-    interesting_origin: Optional[InterestingOrigin] = attr.ib()
+    interesting_origin: InterestingOrigin | None = attr.ib()
     nodes: tuple[ChoiceNode, ...] = attr.ib(eq=False, repr=False)
     length: int = attr.ib()
     output: str = attr.ib()
-    expected_exception: Optional[BaseException] = attr.ib()
-    expected_traceback: Optional[str] = attr.ib()
+    expected_exception: BaseException | None = attr.ib()
+    expected_traceback: str | None = attr.ib()
     has_discards: bool = attr.ib()
     target_observations: TargetObservations = attr.ib()
     tags: frozenset[StructuralCoverageTag] = attr.ib()
     spans: Spans = attr.ib(repr=False, eq=False)
     arg_slices: set[tuple[int, int]] = attr.ib(repr=False)
     slice_comments: dict[tuple[int, int], str] = attr.ib(repr=False)
-    misaligned_at: Optional[MisalignedAt] = attr.ib(repr=False)
-    cannot_proceed_scope: Optional[CannotProceedScopeT] = attr.ib(repr=False)
+    misaligned_at: MisalignedAt | None = attr.ib(repr=False)
+    cannot_proceed_scope: CannotProceedScopeT | None = attr.ib(repr=False)
 
     def as_result(self) -> "ConjectureResult":
         return self
@@ -607,11 +602,11 @@ class ConjectureData:
     @classmethod
     def for_choices(
         cls,
-        choices: Sequence[Union[ChoiceTemplate, ChoiceT]],
+        choices: Sequence[ChoiceTemplate | ChoiceT],
         *,
-        observer: Optional[DataObserver] = None,
-        provider: Union[type, PrimitiveProvider] = HypothesisProvider,
-        random: Optional[Random] = None,
+        observer: DataObserver | None = None,
+        provider: PrimitiveProvider | type[PrimitiveProvider] = HypothesisProvider,
+        random: Random | None = None,
     ) -> "ConjectureData":
         from hypothesis.internal.conjecture.engine import choice_count
 
@@ -626,12 +621,12 @@ class ConjectureData:
     def __init__(
         self,
         *,
-        random: Optional[Random],
-        observer: Optional[DataObserver] = None,
-        provider: Union[type, PrimitiveProvider] = HypothesisProvider,
-        prefix: Optional[Sequence[Union[ChoiceTemplate, ChoiceT]]] = None,
-        max_choices: Optional[int] = None,
-        provider_kw: Optional[dict[str, Any]] = None,
+        random: Random | None,
+        observer: DataObserver | None = None,
+        provider: PrimitiveProvider | type[PrimitiveProvider] = HypothesisProvider,
+        prefix: Sequence[ChoiceTemplate | ChoiceT] | None = None,
+        max_choices: int | None = None,
+        provider_kw: dict[str, Any] | None = None,
     ) -> None:
         from hypothesis.internal.conjecture.engine import BUFFER_SIZE
 
@@ -661,8 +656,8 @@ class ConjectureData:
         threadlocal.global_test_counter += 1
         self.start_time = time.perf_counter()
         self.gc_start_time = gc_cumulative_time()
-        self.events: dict[str, Union[str, int, float]] = {}
-        self.interesting_origin: Optional[InterestingOrigin] = None
+        self.events: dict[str, str | int | float] = {}
+        self.interesting_origin: InterestingOrigin | None = None
         self.draw_times: dict[str, float] = {}
         self._stateful_run_times: dict[str, float] = defaultdict(float)
         self.max_depth = 0
@@ -673,7 +668,7 @@ class ConjectureData:
         )
         assert isinstance(self.provider, PrimitiveProvider)
 
-        self.__result: Optional[ConjectureResult] = None
+        self.__result: ConjectureResult | None = None
 
         # Observations used for targeted search.  They'll be aggregated in
         # ConjectureRunner.generate_new_examples and fed to TargetSelector.
@@ -687,7 +682,7 @@ class ConjectureData:
         # Normally unpopulated but we need this in the niche case
         # that self.as_result() is Overrun but we still want the
         # examples for reporting purposes.
-        self.__spans: Optional[Spans] = None
+        self.__spans: Spans | None = None
 
         # We want the top level span to have depth 0, so we start
         # at -1.
@@ -703,23 +698,23 @@ class ConjectureData:
             PredicateCounts
         )
 
-        self._sampled_from_all_strategies_elements_message: Optional[
-            tuple[str, object]
-        ] = None
-        self._shared_strategy_draws: dict[Hashable, tuple[int, Any]] = {}
-        self._shared_data_strategy: Optional[DataObject] = None
-        self._stateful_repr_parts: Optional[list[Any]] = None
-        self.states_for_ids: Optional[dict[int, RandomState]] = None
-        self.seeds_to_states: Optional[dict[Any, RandomState]] = None
+        self._sampled_from_all_strategies_elements_message: (
+            tuple[str, object] | None
+        ) = None
+        self._shared_strategy_draws: dict[Hashable, tuple[Any, SearchStrategy]] = {}
+        self._shared_data_strategy: DataObject | None = None
+        self._stateful_repr_parts: list[Any] | None = None
+        self.states_for_ids: dict[int, RandomState] | None = None
+        self.seeds_to_states: dict[Any, RandomState] | None = None
         self.hypothesis_runner: Any = not_set
 
-        self.expected_exception: Optional[BaseException] = None
-        self.expected_traceback: Optional[str] = None
+        self.expected_exception: BaseException | None = None
+        self.expected_traceback: str | None = None
 
         self.prefix = prefix
         self.nodes: tuple[ChoiceNode, ...] = ()
-        self.misaligned_at: Optional[MisalignedAt] = None
-        self.cannot_proceed_scope: Optional[CannotProceedScopeT] = None
+        self.misaligned_at: MisalignedAt | None = None
+        self.cannot_proceed_scope: CannotProceedScopeT | None = None
         self.start_span(TOP_LABEL)
 
     def __repr__(self) -> str:
@@ -749,7 +744,7 @@ class ConjectureData:
         constraints: IntegerConstraints,
         *,
         observe: bool,
-        forced: Optional[int],
+        forced: int | None,
     ) -> int: ...
 
     @overload
@@ -759,7 +754,7 @@ class ConjectureData:
         constraints: FloatConstraints,
         *,
         observe: bool,
-        forced: Optional[float],
+        forced: float | None,
     ) -> float: ...
 
     @overload
@@ -769,7 +764,7 @@ class ConjectureData:
         constraints: StringConstraints,
         *,
         observe: bool,
-        forced: Optional[str],
+        forced: str | None,
     ) -> str: ...
 
     @overload
@@ -779,7 +774,7 @@ class ConjectureData:
         constraints: BytesConstraints,
         *,
         observe: bool,
-        forced: Optional[bytes],
+        forced: bytes | None,
     ) -> bytes: ...
 
     @overload
@@ -789,7 +784,7 @@ class ConjectureData:
         constraints: BooleanConstraints,
         *,
         observe: bool,
-        forced: Optional[bool],
+        forced: bool | None,
     ) -> bool: ...
 
     def _draw(
@@ -798,7 +793,7 @@ class ConjectureData:
         constraints: ChoiceConstraintsT,
         *,
         observe: bool,
-        forced: Optional[ChoiceT],
+        forced: ChoiceT | None,
     ) -> ChoiceT:
         # this is somewhat redundant with the length > max_length check at the
         # end of the function, but avoids trying to use a null self.random when
@@ -870,12 +865,12 @@ class ConjectureData:
 
     def draw_integer(
         self,
-        min_value: Optional[int] = None,
-        max_value: Optional[int] = None,
+        min_value: int | None = None,
+        max_value: int | None = None,
         *,
-        weights: Optional[dict[int, float]] = None,
+        weights: dict[int, float] | None = None,
         shrink_towards: int = 0,
-        forced: Optional[int] = None,
+        forced: int | None = None,
         observe: bool = True,
     ) -> int:
         # Validate arguments
@@ -917,7 +912,7 @@ class ConjectureData:
         # TODO: consider supporting these float widths at the choice sequence
         # level in the future.
         # width: Literal[16, 32, 64] = 64,
-        forced: Optional[float] = None,
+        forced: float | None = None,
         observe: bool = True,
     ) -> float:
         assert smallest_nonzero_magnitude > 0
@@ -957,7 +952,7 @@ class ConjectureData:
         *,
         min_size: int = 0,
         max_size: int = COLLECTION_DEFAULT_MAX_SIZE,
-        forced: Optional[str] = None,
+        forced: str | None = None,
         observe: bool = True,
     ) -> str:
         assert forced is None or min_size <= len(forced) <= max_size
@@ -980,7 +975,7 @@ class ConjectureData:
         min_size: int = 0,
         max_size: int = COLLECTION_DEFAULT_MAX_SIZE,
         *,
-        forced: Optional[bytes] = None,
+        forced: bytes | None = None,
         observe: bool = True,
     ) -> bytes:
         assert forced is None or min_size <= len(forced) <= max_size
@@ -995,7 +990,7 @@ class ConjectureData:
         self,
         p: float = 0.5,
         *,
-        forced: Optional[bool] = None,
+        forced: bool | None = None,
         observe: bool = True,
     ) -> bool:
         assert (forced is not True) or p > 0
@@ -1049,7 +1044,7 @@ class ConjectureData:
         choice_type: ChoiceTypeT,
         constraints: ChoiceConstraintsT,
         *,
-        forced: Optional[ChoiceT],
+        forced: ChoiceT | None,
     ) -> ChoiceT:
         assert self.prefix is not None
         # checked in _draw
@@ -1133,7 +1128,7 @@ class ConjectureData:
         self.index += 1
         return choice
 
-    def as_result(self) -> Union[ConjectureResult, _Overrun]:
+    def as_result(self) -> ConjectureResult | _Overrun:
         """Convert the result of running this test into
         either an Overrun object or a ConjectureResult."""
 
@@ -1174,8 +1169,8 @@ class ConjectureData:
     def draw(
         self,
         strategy: "SearchStrategy[Ex]",
-        label: Optional[int] = None,
-        observe_as: Optional[str] = None,
+        label: int | None = None,
+        observe_as: str | None = None,
     ) -> "Ex":
         from hypothesis.internal.observability import observability_enabled
         from hypothesis.strategies._internal.lazy import unwrap_strategies
@@ -1318,7 +1313,7 @@ class ConjectureData:
         self,
         values: Sequence[T],
         *,
-        forced: Optional[T] = None,
+        forced: T | None = None,
         observe: bool = True,
     ) -> T:
         forced_i = None if forced is None else values.index(forced)
@@ -1333,7 +1328,7 @@ class ConjectureData:
     def conclude_test(
         self,
         status: Status,
-        interesting_origin: Optional[InterestingOrigin] = None,
+        interesting_origin: InterestingOrigin | None = None,
     ) -> NoReturn:
         assert (interesting_origin is None) or (status == Status.INTERESTING)
         self.__assert_not_frozen("conclude_test")
@@ -1345,7 +1340,7 @@ class ConjectureData:
     def mark_interesting(self, interesting_origin: InterestingOrigin) -> NoReturn:
         self.conclude_test(Status.INTERESTING, interesting_origin)
 
-    def mark_invalid(self, why: Optional[str] = None) -> NoReturn:
+    def mark_invalid(self, why: str | None = None) -> NoReturn:
         if why is not None:
             self.events["invalid because"] = why
         self.conclude_test(Status.INVALID)
