@@ -16,7 +16,6 @@ import time
 from contextlib import contextmanager, nullcontext
 from random import Random
 from threading import RLock
-from typing import Optional
 
 import pytest
 
@@ -80,10 +79,10 @@ class PrngProvider(PrimitiveProvider):
 
     def draw_integer(
         self,
-        min_value: Optional[int] = None,
-        max_value: Optional[int] = None,
+        min_value: int | None = None,
+        max_value: int | None = None,
         *,
-        weights: Optional[dict[int, float]] = None,
+        weights: dict[int, float] | None = None,
         shrink_towards: int = 0,
     ) -> int:
         # shrink_towards is fully ignored here. It would be nice to implement
@@ -166,10 +165,7 @@ class PrngProvider(PrimitiveProvider):
         # cap max size for performance
         max_size = 100 if max_size is None else min(max_size, 100)
         size = self.prng.randint(min_size, max_size)
-        try:
-            return self.prng.randbytes(size)
-        except AttributeError:  # randbytes is new in python 3.9
-            return bytes(self.prng.randint(0, 255) for _ in range(size))
+        return self.prng.randbytes(size)
 
 
 _temp_register_backend_lock = RLock()
@@ -178,9 +174,8 @@ _temp_register_backend_lock = RLock()
 # same as with_register_backend, but adds a lock for our threading tests.
 @contextmanager
 def temp_register_backend(name, provider_cls):
-    with _temp_register_backend_lock:
-        with with_register_backend(name, provider_cls):
-            yield
+    with _temp_register_backend_lock, with_register_backend(name, provider_cls):
+        yield
 
 
 @pytest.mark.parametrize(
@@ -308,14 +303,11 @@ class InvalidLifetime(TrivialProvider):
 
 
 def test_invalid_lifetime():
-    with temp_register_backend("invalid_lifetime", InvalidLifetime):
-        # NOTE: For compatibility with Python 3.9's LL(1)
-        # parser, this is written as a nested with-statement,
-        # instead of a compound one.
-        with pytest.raises(InvalidArgument):
-            ConjectureRunner(
-                lambda: True, settings=settings(backend="invalid_lifetime")
-            )
+    with (
+        temp_register_backend("invalid_lifetime", InvalidLifetime),
+        pytest.raises(InvalidArgument),
+    ):
+        ConjectureRunner(lambda: True, settings=settings(backend="invalid_lifetime"))
 
 
 function_lifetime_init_count = 0
@@ -660,18 +652,17 @@ def test_can_generate_from_all_available_providers(backend, strategy):
     def f(x):
         raise ValueError
 
-    with pytest.raises(ValueError):
-        # NOTE: For compatibility with Python 3.9's LL(1)
-        # parser, this is written as a nested with-statement,
-        # instead of a compound one.
-        with (
+    with (
+        pytest.raises(ValueError),
+        (
             pytest.warns(
                 HypothesisWarning, match="/dev/urandom is not available on windows"
             )
             if backend == "hypothesis-urandom" and WINDOWS
             else nullcontext()
-        ):
-            f()
+        ),
+    ):
+        f()
 
 
 def test_saves_on_fatal_error_with_backend():
