@@ -46,6 +46,7 @@ from hypothesis.strategies import binary, data, integers, just, lists
 from tests.common.utils import (
     Why,
     capture_out,
+    skipif_threading,
     validate_deprecation,
     xfail_on_crosshair,
 )
@@ -407,6 +408,7 @@ class FailsEventually(RuleBasedStateMachine):
 FailsEventually.TestCase.settings = Settings(stateful_step_count=5)
 
 
+@skipif_threading
 def test_can_explicitly_pass_settings():
     run_state_machine_as_test(FailsEventually)
     try:
@@ -432,6 +434,7 @@ def test_runner_that_checks_factory_produced_a_machine():
         run_state_machine_as_test(object)
 
 
+@skipif_threading
 def test_settings_attribute_is_validated():
     real_settings = FailsEventually.TestCase.settings
     try:
@@ -453,14 +456,10 @@ def test_saves_failing_example_in_database():
 
 
 def test_can_run_with_no_db():
-    with deterministic_PRNG():
-        # NOTE: For compatibility with Python 3.9's LL(1)
-        # parser, this is written as a nested with-statement,
-        # instead of a compound one.
-        with raises(AssertionError):
-            run_state_machine_as_test(
-                DepthMachine, settings=Settings(database=None, max_examples=10_000)
-            )
+    with deterministic_PRNG(), raises(AssertionError):
+        run_state_machine_as_test(
+            DepthMachine, settings=Settings(database=None, max_examples=10_000)
+        )
 
 
 def test_stateful_double_rule_is_forbidden(recwarn):
